@@ -1,7 +1,7 @@
 /* Copyright (c) 2001 Matej Pfajfar.
  * Copyright (c) 2001-2004, Roger Dingledine.
  * Copyright (c) 2004-2006, Roger Dingledine, Nick Mathewson.
- * Copyright (c) 2007-2020, The Tor Project, Inc. */
+ * Copyright (c) 2007-2021, The Tor Project, Inc. */
 /* See LICENSE for licensing information */
 
 /**
@@ -352,7 +352,6 @@ check_and_prune_server_ports(smartlist_t *ports,
   int n_orport_listeners = 0;
   int n_dirport_advertised = 0;
   int n_dirport_listeners = 0;
-  int n_dirport_listeners_v4 = 0;
   int n_low_port = 0;
   int r = 0;
 
@@ -363,12 +362,8 @@ check_and_prune_server_ports(smartlist_t *ports,
     if (port->type == CONN_TYPE_DIR_LISTENER) {
       if (! port->server_cfg.no_advertise)
         ++n_dirport_advertised;
-      if (! port->server_cfg.no_listen) {
+      if (! port->server_cfg.no_listen)
         ++n_dirport_listeners;
-        if (port_binds_ipv4(port)) {
-          ++n_dirport_listeners_v4;
-        }
-      }
     } else if (port->type == CONN_TYPE_OR_LISTENER) {
       if (! port->server_cfg.no_advertise) {
         ++n_orport_advertised;
@@ -413,12 +408,6 @@ check_and_prune_server_ports(smartlist_t *ports,
              "address. Tor needs to listen on an IPv4 address too.");
     r = -1;
   }
-  if (n_dirport_advertised && n_dirport_listeners_v4 == 0) {
-    log_warn(LD_CONFIG, "We are listening on a non-IPv4 DirPort. This is not "
-                        "allowed. Consider either setting an IPv4 address or "
-                        "simply removing it because it is not used anymore.");
-    r = -1;
-  }
 
   if (n_low_port && options->AccountingMax &&
       (!have_capability_support() || options->KeepBindCapabilities == 0)) {
