@@ -1,7 +1,7 @@
 /* Copyright (c) 2001 Matej Pfajfar.
  * Copyright (c) 2001-2004, Roger Dingledine.
  * Copyright (c) 2004-2006, Roger Dingledine, Nick Mathewson.
- * Copyright (c) 2007-2020, The Tor Project, Inc. */
+ * Copyright (c) 2007-2021, The Tor Project, Inc. */
 /* See LICENSE for licensing information */
 
 /**
@@ -206,24 +206,16 @@ bwhist_note_dir_bytes_read(uint64_t num_bytes, time_t when)
   add_obs(dir_read_array, when, num_bytes);
 }
 
-/**
- * Helper: Return the largest value in b->maxima.  (This is equal to the
+/** Helper: Return the largest value in b->maxima.  (This is equal to the
  * most bandwidth used in any NUM_SECS_ROLLING_MEASURE period for the last
  * NUM_SECS_BW_SUM_IS_VALID seconds.)
- *
- * Also include the current period if we have been observing it for
- * at least min_observation_time seconds.
  */
 STATIC uint64_t
-find_largest_max(bw_array_t *b, int min_observation_time)
+find_largest_max(bw_array_t *b)
 {
   int i;
   uint64_t max;
-  time_t period_start = b->next_period - NUM_SECS_BW_SUM_INTERVAL;
-  if (b->cur_obs_time > period_start + min_observation_time)
-    max = b->max_total;
-  else
-    max = 0;
+  max=0;
   for (i=0; i<NUM_TOTALS; ++i) {
     if (b->maxima[i]>max)
       max = b->maxima[i];
@@ -241,9 +233,8 @@ MOCK_IMPL(int,
 bwhist_bandwidth_assess,(void))
 {
   uint64_t w,r;
-  int min_obs_time = get_options()->TestingMinTimeToReportBandwidth;
-  r = find_largest_max(read_array, min_obs_time);
-  w = find_largest_max(write_array, min_obs_time);
+  r = find_largest_max(read_array);
+  w = find_largest_max(write_array);
   if (r>w)
     return (int)(((double)w)/NUM_SECS_ROLLING_MEASURE);
   else
