@@ -1,4 +1,4 @@
-/* Copyright (c) 2016-2020, The Tor Project, Inc. */
+/* Copyright (c) 2016-2021, The Tor Project, Inc. */
 /* See LICENSE for licensing information */
 
 #define PROTOVER_PRIVATE
@@ -348,10 +348,13 @@ test_protover_supports_version(void *arg)
 /* Deprecated HSIntro versions */
 #define PROTOVER_HS_INTRO_DEPRECATED_1 1
 #define PROTOVER_HS_INTRO_DEPRECATED_2 2
+/* Highest supported HSv2 introduce protocol version.
+ * It's not clear if we actually support version 2, see #25068. */
+#define PROTOVER_HS_INTRO_V2 3
 
 /* HSv2 Rend and HSDir protocol versions. */
 #define PROTOVER_HS_RENDEZVOUS_POINT_V2 1
-#define PROTOVER_HSDIR_V2 2
+#define PROTOVER_HSDIR_V2 1
 
 /* DirCache, Desc, Microdesc, and Cons protocol versions. */
 #define PROTOVER_DIRCACHE_V1 1
@@ -430,6 +433,12 @@ test_protover_supported_protocols(void *arg)
   tt_assert(!protocol_list_supports_protocol(supported_protocols,
                                             PRT_HSINTRO,
                                             PROTOVER_HS_INTRO_DEPRECATED_2));
+  /* We could test legacy HSIntro by calling rend_service_update_descriptor(),
+   * and checking the protocols field. But that's unlikely to change, so
+   * we just use a hard-coded value. */
+  tt_assert(protocol_list_supports_protocol(supported_protocols,
+                                            PRT_HSINTRO,
+                                            PROTOVER_HS_INTRO_V2));
   /* Test for HSv3 HSIntro */
   tt_assert(protocol_list_supports_protocol(supported_protocols,
                                             PRT_HSINTRO,
@@ -597,10 +606,10 @@ test_protover_vote_roundtrip_ours(void *args)
   (void) args;
   const char *examples[] = {
     protover_get_supported_protocols(),
-    protover_get_recommended_client_protocols(),
-    protover_get_recommended_relay_protocols(),
-    protover_get_required_client_protocols(),
-    protover_get_required_relay_protocols(),
+    DIRVOTE_RECOMMEND_RELAY_PROTO,
+    DIRVOTE_RECOMMEND_CLIENT_PROTO,
+    DIRVOTE_REQUIRE_RELAY_PROTO,
+    DIRVOTE_REQUIRE_CLIENT_PROTO,
   };
   unsigned u;
   smartlist_t *votes = smartlist_new();
@@ -641,7 +650,7 @@ test_protover_vote_roundtrip_ours(void *args)
  */
 #define PROTOVER(proto_string, version_macro) \
   (proto_string "=" STR(version_macro))
-#endif
+#endif /* defined(COCCI) */
 
 #define DEBUG_PROTOVER(flags) \
   STMT_BEGIN \
